# Import the math library so we have functions like cos, sin, sqrt, and
# constants like pi
import math


def cartesian_to_polar(x, y):
    # NOTE! This code only works for x > 0 and y > 0

    # If x == y == 0, this is a weird boundary case we accomodate for
    if x == y and y == 0:
        return 0, 0

    # Get the polar radial distance
    r = math.sqrt(x ** 2 + y ** 2)
    # Get the polar angle
    # NOTE! We need to accomodate for x = 0, as we will be dividing
    if x == 0:
        # It should be either positive or negative infinity, depending on
        # the sign of y
        z = float('inf') * y / abs(y)
    else:
        z = float(y) / float(x)
    theta = math.atan(z)
    # Convert angle to degrees, as default math.atan is radians
    theta *= 180.0 / math.pi
    # Now, we only have the angle
    return r, theta


# Should get r = 1, t = 90
x, y = 0, 1
r, t = cartesian_to_polar(x, y)

# NOTE, we can print the results in many ways!
print("Converted (%.2f, %.2f) to (r, theta) = (%.2f, %.2f)" % (x, y, r, t))
print("Converted (" + str(x) + ", " + str(y) +
      ") to (r, theta) = (" + str(r) + ", " + str(t) + ")")
print("Converted (", x, ", ", y, ") to (r, theta) = (", r, ", ", t, ")")
